@@ -1,14 +1,10 @@
-#[cfg(target_family = "unix")]
-use std::os::unix::net::UnixStream;
-use std::{net::TcpStream, ops::Deref};
-
-use net2::TcpStreamExt;
+use std::ops::Deref;
 
 use log::info;
 
 use pallas::network::{
-    miniprotocols::{handshake::n2n, run_agent, MAINNET_MAGIC},
-    multiplexer::{Channel, Multiplexer},
+    miniprotocols::{handshake, run_agent, MAINNET_MAGIC},
+    multiplexer::Channel,
 };
 
 use serde::Deserialize;
@@ -17,8 +13,8 @@ use crate::{
     mapper::{Config as MapperConfig, EventWriter},
     pipelining::{new_inter_stage_channel, PartialBootstrapResult, SourceProvider},
     sources::{
-        common::{AddressArg, BearerKind, MagicArg, PointArg},
-        define_start_point, IntersectArg,
+        common::{AddressArg, MagicArg, PointArg},
+        define_start_point, setup_multiplexer, FinalizeConfig, IntersectArg, RetryPolicy,
     },
     utils::{ChainWellKnownInfo, WithUtils},
     Error,
@@ -53,43 +49,33 @@ pub struct Config {
     /// will need some time to fill up the buffer before sending the 1st event.
     #[serde(default)]
     pub min_depth: usize,
+
+    pub retry_policy: Option<RetryPolicy>,
+
+    pub finalize: Option<FinalizeConfig>,
 }
 
 fn do_handshake(channel: &mut Channel, magic: u64) -> Result<(), Error> {
-    let versions = n2n::VersionTable::v6_and_above(magic);
-    let agent = run_agent(n2n::Client::initial(versions), channel)?;
+    let versions = handshake::n2n::VersionTable::v6_and_above(magic);
+    let agent = run_agent(handshake::Initiator::initial(versions), channel)?;
     info!("handshake output: {:?}", agent.output);
 
     match agent.output {
-        n2n::Output::Accepted(_, _) => Ok(()),
+        handshake::Output::Accepted(_, _) => Ok(()),
         _ => Err("couldn't agree on handshake version".into()),
     }
 }
 
-#[cfg(target_family = "unix")]
-fn setup_unix_multiplexer(path: &str) -> Result<Multiplexer, Error> {
-    let unix = UnixStream::connect(path)?;
-
-    Multiplexer::setup(unix, &[0, 2, 3])
-}
-
-fn setup_tcp_multiplexer(address: &str) -> Result<Multiplexer, Error> {
-    let tcp = TcpStream::connect(address)?;
-    tcp.set_nodelay(true)?;
-    tcp.set_keepalive_ms(Some(30_000u32))?;
-
-    Multiplexer::setup(tcp, &[0, 2, 3])
-}
-
 impl SourceProvider for WithUtils<Config> {
     fn bootstrap(&self) -> PartialBootstrapResult {
         let (output_tx, output_rx) = new_inter_stage_channel(None);
 
-        let mut muxer = match self.inner.address.0 {
-            BearerKind::Tcp => setup_tcp_multiplexer(&self.inner.address.1)?,
-            #[cfg(target_family = "unix")]
-            BearerKind::Unix => setup_unix_multiplexer(&self.inner.address.1)?,
-        };
+        let mut muxer = setup_multiplexer(
+            &self.inner.address.0,
+            &self.inner.address.1,
+            &[0, 2, 3],
+            &self.inner.retry_policy,
+        )?;
 
         let magic = match &self.inner.magic {
             Some(m) => *m.deref(),
@@ -117,18 +103,30 @@ impl SourceProvider for WithUtils<Config> {
 
         let min_depth = self.inner.min_depth;
         let cs_writer = writer.clone();
-        let cs_handle = std::thread::spawn(move || {
-            observe_headers_forever(cs_channel, cs_writer, known_points, headers_tx, min_depth)
-                .expect("chainsync loop failed");
+        let finalize = self.inner.finalize.clone();
+        let _cs_handle = std::thread::spawn(move || {
+            observe_headers_forever(
+                cs_channel,
+                cs_writer,
+                known_points,
+                headers_tx,
+                min_depth,
+                finalize,
+            )
+            .expect("chainsync loop failed");
+
+            log::info!("observe headers thread ended");
         });
 
         let bf_channel = muxer.use_channel(3);
         let bf_writer = writer;
-        let _bf_handle = std::thread::spawn(move || {
+        let bf_handle = std::thread::spawn(move || {
             fetch_blocks_forever(bf_channel, bf_writer, headers_rx)
                 .expect("blockfetch loop failed");
+
+            log::info!("block fetch thread ended");
         });
 
-        Ok((cs_handle, output_rx))
+        Ok((bf_handle, output_rx))
     }
 }
